@@ -49,7 +49,7 @@ class DeclarativeAdapter : public QObject
     Q_PROPERTY(QQmlListProperty<DeclarativeDevice> devices READ devices NOTIFY devicesChanged)
 
 public:
-    explicit DeclarativeAdapter(BluezQt::AdapterPtr adapter, QObject *parent = Q_NULLPTR);
+    explicit DeclarativeAdapter(BluezQt::AdapterPtr adapter, QObject *parent = nullptr);
 
     QString ubi() const;
 
